@@ -436,7 +436,7 @@ fn run_command(command: opts::Command) -> Result<CommandExitStatus> {
                 std::process::exit(status.code().unwrap_or(-159));
             }
             opts::Crate::Verify { crate_, opts } => {
-                deps::verify_deps(crate_, opts)?;
+                return deps::verify_deps(crate_, opts);
             }
             opts::Crate::Mvp { crate_, opts } => {
                 deps::crate_mvps(crate_, opts)?;
@@ -454,7 +454,7 @@ fn run_command(command: opts::Command) -> Result<CommandExitStatus> {
             }
             opts::Crate::Clean(args) => {
                 if args.crate_.is_empty() && are_we_called_from_goto_shell().is_none() {
-                    clean_all_unclean_crates()?;
+                    clean_all_crates_with_digest_mismatch()?;
                 } else {
                     handle_goto_mode_command(&args, |sel| clean_crate(sel))?;
                 }
@@ -626,7 +626,7 @@ fn run_command(command: opts::Command) -> Result<CommandExitStatus> {
         opts::Command::Update(args) => repo_update(args)?,
 
         opts::Command::Verify { crate_, opts } => {
-            deps::verify_deps(crate_, opts)?;
+            return deps::verify_deps(crate_, opts);
         }
     }
 
