@@ -1,5 +1,5 @@
-use std::io::Write;
 use std::ffi::*;
+use std::io::Write;
 use std::path::*;
 use std::process::*;
 
@@ -7,8 +7,9 @@ use std::process::*;
 fn creates_new_id_implicitly() {
     let c = Cli::new();
     let empty_id = c.run(&["id", "query", "own"], "");
-    assert!(!empty_id.status.success());
-    assert!(c.run(&["id", "trust", "--level=medium", "FYlr8YoYGVvDwHQxqEIs89reKKDy-oWisoO0qXXEfHE"], "").status.success());
+    assert!(!empty_id.status.success(), "{:?}", empty_id);
+    let trust = c.run(&["id", "trust", "--level=medium", "FYlr8YoYGVvDwHQxqEIs89reKKDy-oWisoO0qXXEfHE"], "");
+    assert!(trust.status.success(), "{:?}", trust);
     assert!(c.run(&["id", "query", "own"], "").status.success());
 }
 
@@ -25,6 +26,7 @@ impl Cli {
         }
     }
 
+    #[track_caller]
     pub fn run(&self, args: &[impl AsRef<OsStr>], stdin_data: impl Into<String>) -> Output {
         let mut child = Command::new(&self.exe)
             .env("CARGO_CREV_ROOT_DIR_OVERRIDE", self.home.path())
@@ -36,7 +38,7 @@ impl Cli {
             .arg("crev")
             .args(args)
             .spawn()
-            .expect(&format!("Failed to run {}", self.exe.display()));
+            .unwrap_or_else(|_| panic!("Failed to run {}", self.exe.display()));
 
         let stdin_data = stdin_data.into();
         let mut stdin = child.stdin.take().unwrap();
